@@ -1,15 +1,8 @@
-
-sdk_version = "0.0.1"
+sdk_version = "0.0.18"
 api_base = "https://v2.api.audio"
 api_key = None
 
-api_version = "0.0.1"
-verify_ssl_certs = True
-proxy = None
-default_http_client = None
 app_info = None
-enable_telemetry = True
-max_network_retries = 0
 
 
 from audiostack import content as Content
@@ -20,6 +13,8 @@ from audiostack.docs.docs import Documentation
 
 billing_session = 0
 
+
 def credits_used_in_this_session():
     return float("{:.2f}".format(billing_session))
-    
\ No newline at end of file
+
+
