@@ -3,12 +3,11 @@ from audiostack.helpers.request_types import RequestTypes
 from audiostack.helpers.api_item import APIResponseItem
 from audiostack.helpers.api_list import APIResponseList
 
-class Voice():
-    
+
+class Voice:
     interface = RequestInterface(family="speech/voice")
-    
+
     class Item(APIResponseItem):
-        
         def __init__(self, response) -> None:
             super().__init__(response)
             self.provider = self.data["provider"]
@@ -20,23 +19,17 @@ class Voice():
 
         def resolve_item(self, list_type, item):
             if list_type == "voices":
-                return Voice.Item({"data" : item})
+                return Voice.Item({"data": item})
             else:
                 raise Exception()
 
-    
     @staticmethod
     def list() -> list:
         r = Voice.interface.send_request(rtype=RequestTypes.GET, route="")
-        print(r)
         return Voice.List(r, list_type="voices")
 
-
-    class Parameter():
-        
+    class Parameter:
         @staticmethod
         def get() -> dict:
             r = Voice.interface.send_request(rtype=RequestTypes.GET, route="parameter")
             return APIResponseItem(r)
-
-   
\ No newline at end of file
